@@ -53,14 +53,14 @@ sub run_callback {
 # make string from hash config, using URL encoding to escape special chars
 sub cfg2str {
     my Net::IMP::Base $self = shift;
-    my $cfg = shift;
+    my %cfg = @_;
     return join('&', map {
-	my $v = $cfg->{$_};
+	my $v = $cfg{$_};
 	# only encode really necessary stuff
 	s{([=&%\x00-\x20\x7f-\xff])}{ sprintf("%%%02X",ord($1)) }eg; # key
 	$v =~s{([&%\x00-\x20\x7f-\xff])}{ sprintf("%%%02X",ord($1)) }eg; # value
 	"$_=$v"
-    } sort keys %$cfg);
+    } sort keys %cfg);
 }
 
 # make has config from string created by cfg2str
@@ -74,7 +74,7 @@ sub str2cfg {
 	exists $cfg{$k} and croak "duplicate definition for key $k";
 	$cfg{$k} = $v;
     }
-    return \%cfg;
+    return %cfg;
 }
 
 1;
@@ -215,14 +215,25 @@ from a single string:
 
 =over 4
 
-=item $class->cfg2str(\%config) -> $string
+=item $class->cfg2str(%config) -> $string
 
 Creates a string from a (configuration) hash.
 The output is similar to encoded query parameters in URLs.
 
-=item $class->str2cfg($string) -> \%config
+=item $class->str2cfg($string) -> %config
 
 Parses a configuration string generated by C<cfg2str> and restores the
 configuration hash.
 
 =back
+
+=head1 AUTHOR
+
+Steffen Ullrich <sullr@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright by Steffen Ullrich.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
