@@ -9,7 +9,7 @@ use fields (
     'off_not_fwd',    # offset up to which not yet forwarded
     'rules',          # rules from config
     'ignore_order',   # ignore_order from config
-    'max_open',       # max_open from config
+    'max_unbound',    # max_unbound from config
 );
 
 use Net::IMP; # import IMP_ constants
@@ -27,10 +27,15 @@ sub new_analyzer {
 
     # set buf to '' for dir where we have rules, else leave undef
     my @buf;
-    $buf[$_->[0]] = '' for (@rules);
+    $buf[$_->{dir}] = '' for (@rules);
+
+    # make sure that no rule matches empty string
+    for(@rules) {
+	'' =~ $_->{rx} and croak("regex '$_->{rx}' matches empty string");
+    }
 
     my $ignore_order = delete $args{ignore_order};
-    my $max_open     = delete $args{max_open} // [];
+    my $max_unbound  = delete $args{max_unbound} // [];
     my Net::IMP::ProtocolPinning $self = $class->SUPER::new_analyzer(
 	%args,
 
@@ -43,12 +48,13 @@ sub new_analyzer {
 	off_not_fwd => [0,0],
 
 	# -- configuration ------
-	# rules as [dir,rxlen,rx],[dir,rxlen,rx],...
+	# array of rules, rule is hash with dir,rxlen,rx
 	rules => \@rules,
 	# if true server can send even if we except client data first etc
 	ignore_order => $ignore_order,,
-	# maximum number of open data if we have no other rule
-	max_open => $max_open,
+	# maximum number of data after all rules for direction are done (e.g
+	# data which cannot be bound to rule)
+	max_unbound => $max_unbound,
     );
 
     return $self;
@@ -64,7 +70,7 @@ sub data {
 	# no rules for $dir, so we don't buffer, but track off_not_fwd
 	# issue DENY when we have too much data open
 	my $open = $self->{off_not_fwd}[$dir] += length($data);
-	if ( defined( my $max = $self->{max_open}[$dir])) {
+	if ( defined( my $max = $self->{max_unbound}[$dir])) {
 	    if ( $open>$max ) {
 		$self->{buf} = undef;
 		$self->run_callback(
@@ -86,7 +92,7 @@ sub data {
 
     my $rules = $self->{rules};
     RULE: while ( @$rules and $buf ne '' ) {
-	my ($rdir,$rxlen,$rx) = @{$rules->[0]};
+	my ($rdir,$rxlen,$rx) = @{$rules->[0]}{qw(dir rxlen rx)};
 
 	if ( $rdir != $dir ) {
 	    if ( ! $self->{ignore_order} ) {
@@ -98,7 +104,7 @@ sub data {
 
 	    # if we have a rule for $dir bring it to front of @$rules and retry
 	    for( my $i=0;$i<@$rules;$i++ ) {
-		if ( $rules->[$i][0] == $dir ) {
+		if ( $rules->[$i]{dir} == $dir ) {
 		    unshift @$rules, splice( @$rules,$i,1 );
 		    redo RULE;
 		}
@@ -163,7 +169,7 @@ sub data {
 	    [ IMP_PASS,1,IMP_MAXOFFSET ],
 	);
     } else {
-	$DEBUG && debug("need more data from ".$rules->[0][0]);
+	$DEBUG && debug("need more data from ".$rules->[0]{dir});
 	if ( $pass ) {
 	    # release data from matched rules
 	    $self->run_callback([ IMP_PASS,$dir,$pass ]);
@@ -172,49 +178,52 @@ sub data {
 }
 
 # cfg2str and str2cfg are redefined because our config hash is deeper
-# nested due to rules and max_open
+# nested due to rules and max_unbound
 sub cfg2str {
     my Net::IMP::ProtocolPinning $self = shift;
-    my $cfg = shift;
-    my %cfg = %$cfg;
+    my %cfg = @_;
 
     my $rules = delete $cfg{rules} or croak("no rules defined");
     # re-insert [[dir,rxlen,rx],... ] as dir0,rxlen0,rx0,dir1,...
     for (my $i=0;$i<@$rules;$i++) {
-	@cfg{ "dir$i","rxlen$i","rx$i" } = @{ $rules->[$i] };
+	@cfg{ "dir$i","rxlen$i","rx$i" } = @{ $rules->[$i] }{qw( dir rxlen rx)};
     }
-    if ( my $max_open = delete $cfg{max_open} ) {
-	# re-insert [mo0,mo1] as max_open0,max_open1
-	@cfg{ 'max_open0', 'max_open1' } = @$max_open;
+    if ( my $max_unbound = delete $cfg{max_unbound} ) {
+	# re-insert [mo0,mo1] as max_unbound0,max_unbound1
+	@cfg{ 'max_unbound0', 'max_unbound1' } = @$max_unbound;
     }
-    return $self->SUPER::cfg2str(\%cfg);
+    return $self->SUPER::cfg2str(%cfg);
 }
 
 sub str2cfg {
     my Net::IMP::ProtocolPinning $self = shift;
-    my $cfg = $self->SUPER::str2cfg(@_);
-    my $rules = $cfg->{rules} = [];
+    my %cfg = $self->SUPER::str2cfg(@_);
+    my $rules = $cfg{rules} = [];
     for( my $i=0;1;$i++ ) {
-	defined( my $dir = delete $cfg->{"dir$i"} ) or last;
-	defined( my $rxlen = delete $cfg->{"rxlen$i"} )
+	defined( my $dir = delete $cfg{"dir$i"} ) or last;
+	defined( my $rxlen = delete $cfg{"rxlen$i"} )
 	    or croak("no rxlen$i defined but dir$i");
-	defined( my $rx = delete $cfg->{"rx$i"} )
+	defined( my $rx = delete $cfg{"rx$i"} )
 	    or croak("no rx$i defined but dir$i");
-	push @$rules, [$dir,$rxlen,$rx];
+	# make sure that rule does not match empty string
+	'' =~ $rx and croak("regex '$rx' matches empty string");
+	push @$rules, { dir => $dir, rxlen => $rxlen, rx => $rx };
+
+
     }
     @$rules or croak("no rules defined");
-    my $max_open = $cfg->{max_open} = [];
+    my $max_unbound = $cfg{max_unbound} = [];
     for(0,1) {
-	$max_open->[$_] = delete $cfg->{"max_open$_"}
-	    if exists $cfg->{"max_open$_"};
+	$max_unbound->[$_] = delete $cfg{"max_unbound$_"}
+	    if exists $cfg{"max_unbound$_"};
     }
 
     # sanity check
-    my %scfg = %$cfg;
-    delete @scfg{'rules','max_open','ignore_order'};
+    my %scfg = %cfg;
+    delete @scfg{'rules','max_unbound','ignore_order'};
     %scfg and croak("unhandled config keys: ".join(' ',sort keys %scfg));
 
-    return $cfg;
+    return %cfg;
 }
 
 
@@ -241,13 +250,16 @@ Net::IMP::ProtocolPinning - IMP plugin for simple protocol matching
     my $factory = Net::IMP::ProtocolPinning->new_factory(
 	rules => [
 	    # SMTP initial handshake
-	    [ 1,512,qr{220 [^\n]*\n} ],         # greeting line from server
-	    [ 0,512,qr{(HELO|EHLO)[^\n]*\n}i ], # HELO|EHLO from client
-	    [ 1,512,qr{250-?[^\n]*\n} ],        # response to helo|ehlo
+	    # greeting line from server
+	    { dir => 1, rxlen => 512, rx => qr{220 [^\n]*\n} },
+	    # HELO|EHLO from client
+	    { dir => 0, rxlen => 512, rx => qr{(HELO|EHLO)[^\n]*\n}i },
+	    # response to helo|ehlo
+	    { dir => 1, rxlen => 512, rx => qr{250-?[^\n]*\n} },
 	],
 	# some clients send w/o initially waiting for server
 	ignore_order => 1,
-	max_open => [ 1024,0 ],
+	max_unbound => [ 1024,0 ],
     );
 
 =head1 DESCRIPTION
@@ -290,19 +302,16 @@ arrive.
 If false, it will cause DENY if data arrive from one direction, but the current
 rule is for the other direction.
 
-=item max_open [SIZE0,SIZE1]
+=item max_unbound [SIZE0,SIZE1]
 
 If there are no more active rules for direction, and ignore_order is true, then
 the application needs to buffer data, until all remaining rules for the other
 direction are matched.
-Using this parameter the amount of buffered data will be limited per
-direction.
+Using this parameter the amount of buffered data which cannot be bound to a rule
+will be limited per direction.
 
 If not set a default of unlimited will be used!
 
-To aid setting parameter from configuration, this parameter can be given as
-string with the sizes delimited by ":".
-
 =back
 
 =head2 Process of Matching Input Against Rules
@@ -326,8 +335,8 @@ If no rule is found for direction, no action will be taken.
 This causes the data to be buffered in the application and they will only be
 released, once all rules have been processed.
 
-To limit the amount of buffered data in this case C<max_open> should be set.
-Buffering more data than C<max_open> for this direction will cause a DENY.
+To limit the amount of buffered data in this case C<max_unbound> should be set.
+Buffering more data than C<max_unbound> for this direction will cause a DENY.
 
 =item *
 
@@ -389,3 +398,14 @@ This might be a problem if there is another rule for the direction, which
 expected the previous rule to "eat" all digits.
 
 =back
+
+=head1 AUTHOR
+
+Steffen Ullrich <sullr@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright by Steffen Ullrich.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
